InterfaceMode

Enum InterfaceMode 

pub enum InterfaceMode {
Show 17 variants IbmpcDd, IbmpcHd, AtaristDd, AtaristHd, AmigaDd, AmigaHd, CpcDd, GenericShugartDd, IbmpcEd, Msx2Dd, C64Dd, EmuShugart, S950Dd, S950Hd, S950DdHd, IbmpcDdHd, Quickdisk,
}
Floppy disk interface mode.

Represents the different interface modes supported by the HxC library. This enum is automatically generated from floppy_ifmode.c.

Variants



IbmpcDd

IBMPC_DD_FLOPPYMODE - PC Interface (720KB/DD Disk)



IbmpcHd

IBMPC_HD_FLOPPYMODE - PC Interface (1.44MB/HD Disk)



AtaristDd

ATARIST_DD_FLOPPYMODE - Atari Interface (720KB/DD Disk)



AtaristHd

ATARIST_HD_FLOPPYMODE - Atari Interface (1.44MB/HD Disk)



AmigaDd

AMIGA_DD_FLOPPYMODE - Amiga Interface (880KB/DD)



AmigaHd

AMIGA_HD_FLOPPYMODE - Amiga Interface (1.76MB/HD)



CpcDd

CPC_DD_FLOPPYMODE - Amstrad CPC Interface



GenericShugartDd

GENERIC_SHUGART_DD_FLOPPYMODE - Shugart Interface



IbmpcEd

IBMPC_ED_FLOPPYMODE - PC Interface (2.88MB/ED Disk)



Msx2Dd

MSX2_DD_FLOPPYMODE - MSX Interface



C64Dd

C64_DD_FLOPPYMODE - C64 Interface



EmuShugart

EMU_SHUGART_FLOPPYMODE - E-mu Interface



S950Dd

S950_DD_FLOPPYMODE - Akai S900/S950 Interface (800KB/DD Disk)



S950Hd

S950_HD_FLOPPYMODE - Akai S950 Interface (1.6MB/HD Disk)



S950DdHd

S950_DD_HD_FLOPPYMODE - Akai S950 Interface (Automatic density selection)



IbmpcDdHd

IBMPC_DD_HD_FLOPPYMODE - PC Interface (Automatic density selection)



Quickdisk

QUICKDISK_FLOPPYMODE - Quickdisk Interface

Implementations

Source

impl InterfaceMode

pub fn mode_name(&self) -> &'static str

Get the interface mode name string

pub fn description(&self) -> &'static str

Get the interface mode description

pub fn from_str(s: &str) -> Option<Self>

Parse from a mode name string

pub fn from_i32(id: i32) -> Option<Self>

Create from raw interface mode ID

pub fn id(&self, hxcfe_ctx: *mut HXCFE) -> i32

Get the interface mode ID from the C library.

The ID is retrieved at runtime by querying the C library with the mode name. Panics if the mode is not found (which indicates a bug in the bindings).

Arguments
  • hxcfe_ctx - The HxC Floppy Emulator context
Returns

The interface mode ID

pub fn all() -> &'static [InterfaceMode]

Get all available interface modes