TrackEncoding

Enum TrackEncoding 

pub enum TrackEncoding {
Show 21 variants IsoibmMfm, AmigaMfm, IsoibmFm, EmuFm, TycomFm, MembrainMfm, AppleiiGcr1, AppleiiGcr2, ApplemacGcr, AppleiiHdddA2Gcr1, AppleiiHdddA2Gcr2, ArburgData, ArburgSystem, NorthstarHsMfm, HeathkitHsFm, DecRx02M2fm, QdMo5, C64Gcr, Victor9kGcr, MicralnHsFm, Unknown,
}
Track encoding type.

Represents the different track encoding formats supported by the HxC library. This enum is automatically generated from floppy_ifmode.c.

Variants



IsoibmMfm

ISOIBM_MFM_ENCODING



AmigaMfm

AMIGA_MFM_ENCODING



IsoibmFm

ISOIBM_FM_ENCODING



EmuFm

EMU_FM_ENCODING



TycomFm

TYCOM_FM_ENCODING



MembrainMfm

MEMBRAIN_MFM_ENCODING



AppleiiGcr1

APPLEII_GCR1_ENCODING



AppleiiGcr2

APPLEII_GCR2_ENCODING



ApplemacGcr

APPLEMAC_GCR_ENCODING



AppleiiHdddA2Gcr1

APPLEII_HDDD_A2_GCR1_ENCODING



AppleiiHdddA2Gcr2

APPLEII_HDDD_A2_GCR2_ENCODING



ArburgData

ARBURG_DATA_ENCODING



ArburgSystem

ARBURG_SYSTEM_ENCODING



NorthstarHsMfm

NORTHSTAR_HS_MFM_ENCODING



HeathkitHsFm

HEATHKIT_HS_FM_ENCODING



DecRx02M2fm

DEC_RX02_M2FM_ENCODING



QdMo5

QD_MO5_ENCODING



C64Gcr

C64_GCR_ENCODING



Victor9kGcr

VICTOR9K_GCR_ENCODING



MicralnHsFm

MICRALN_HS_FM_ENCODING



Unknown

UNKNOWN_ENCODING

Implementations

Source

impl TrackEncoding

pub fn encoding_name(&self) -> &'static str

Get the track encoding name string

pub fn from_str(s: &str) -> Option<Self>

Parse from an encoding name string

pub fn from_u32(value: u32) -> Option<Self>

Convert from a u32 value

pub const fn id(&self) -> u32

Get the track encoding ID (constant value).

Returns the underlying constant value for this encoding type.

pub fn all() -> &'static [TrackEncoding]

Get all available track encodings